package ssw.annotation.Preferences;

import org.eclipse.jface.preference.*;
import org.eclipse.ui.IWorkbenchPreferencePage;
import org.eclipse.ui.IWorkbench;
import ssw.annotation.AnnotationPlugin;
import org.eclipse.jface.preference.IPreferenceStore;

/*
 * Created on 12.4.2005 
 */
/**
 *   Copyright (C) 2005  Stefan Loidl
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *   
 *   eMail: stefanloidl@gmx.net
 *   
 * This class represents a preference page that is contributed to the 
 * Preferences dialog. This page is used to modify preferences only. 
 * They are stored in the preference store that belongs to the main 
 * plug-in class. That way, preferences can be accessed directly via 
 * the preference store.
 * 
 * @version 1.0.0
 * @author Stefan Loidl, 0255886
 */
public class AnnoPreferencePage
	extends FieldEditorPreferencePage
	implements IWorkbenchPreferencePage {
	
	public static final String D_NAME = "namePreference";
	public static final String D_EMAIL = "emailPreference";
	public static final String D_POINTS = "pointsPreference";

	//Invisible preferences referencing their values
	public static final String D_NAME_KEY = "nameKey";
	public static final String D_EMAIL_KEY = "emailKey";
	public static final String D_POINTS_KEY = "pointsKey";

	//Invisible preference values
	private static final String D_NAME_KEY_VALUE = "Name";
	private static final String D_EMAIL_KEY_VALUE = "eMail";
	private static final String D_POINTS_KEY_VALUE = "Points";
	
	//Default values
	private static final String DEFAULT_NAME = "John Doe";
	private static final String DEFAULT_EMAIL = "john@doe.at";
	private static final int DEFAULT_POINTS = 24;
	
	
	/**
	 * Constructor
	 */
	public AnnoPreferencePage() {
		super(GRID);
		setPreferenceStore(AnnotationPlugin.getDefault().getPreferenceStore());
		setDescription(AnnotationPlugin.getResourceString("AP_DEF_AN_SETTINGS"));
		initializeDefaults();
	}
	
	/**
	 * Sets the default values of the preferences.
	 */
	private void initializeDefaults() {
		IPreferenceStore store = getPreferenceStore();
		setDefaults(store);
	}
	
	/**
	 * Set default values.
	 * @param store
	 */
	public static void setDefaults(IPreferenceStore store){
		store.setDefault(D_NAME, DEFAULT_NAME);
		store.setDefault(D_EMAIL,DEFAULT_EMAIL);
		store.setDefault(D_POINTS,DEFAULT_POINTS);
		store.setDefault(D_NAME_KEY,D_NAME_KEY_VALUE);
		store.setDefault(D_EMAIL_KEY,D_EMAIL_KEY_VALUE);
		store.setDefault(D_POINTS_KEY,D_POINTS_KEY_VALUE);
	}
	
/**
 * Creates the field editors. Field editors are abstractions of
 * the common GUI blocks needed to manipulate various types
 * of preferences. Each field editor knows how to save and
 * restore itself.
 */

	public void createFieldEditors() {
		addField(
			new StringFieldEditor(D_NAME, AnnotationPlugin.getResourceString("AP_NAME"), getFieldEditorParent()));
		addField(
				new StringFieldEditor(D_EMAIL, AnnotationPlugin.getResourceString("AP_EMAIL"), getFieldEditorParent()));
		addField(
				new IntegerFieldEditor(D_POINTS, AnnotationPlugin.getResourceString("AP_POINTS"), getFieldEditorParent()));
	}
	
	/**
	 * not used
	 */
	public void init(IWorkbench workbench) {
	}
}